export declare const Context: React.Context<ContextType>;
export declare const defaultHtmlFilter: HtmlFilter;
export declare const remarkLatexEnvironment: () => Transformer;
export declare type OutputType = {
    name?: string;
    ename?: string;
    evalue?: string;
    traceback?: string[];
    data?: {
        'text/plain'?: string[];
        'text/html'?: string[];
        'text/latex'?: string[];
        'image/png'?: string;
        'image/jpeg'?: string;
        'image/gif'?: string;
        'image/svg+xml'?: string;
        'application/javascript'?: string[];
    };
    output_type?: string;
    png?: string;
    jpeg?: string;
    gif?: string;
    svg?: string;
    text?: string[];
    execution_count?: number;
    metadata?: {
        scrolled?: boolean;
    };
};
export declare type CellType = {
    attachments?: {
        [s: string]: {
            [s: string]: string;
        };
    };
    id?: string;
    cell_type?: 'code' | 'markdown' | string;
    execution_count?: number | null;
    prompt_number?: number;
    auto_number?: number;
    metadata?: {
        [s: string]: any;
    };
    source?: string[];
    outputs?: OutputType[];
    input?: string[];
};
export declare type SyntaxThemeType = 'atomDark' | 'cb' | 'coy' | 'darcula' | 'dark' | 'duotoneDark' | 'duotoneEarth' | 'duotoneForest' | 'duotoneLight' | 'duotoneSea' | 'duotoneSpace' | 'funky' | 'ghcolors' | 'hopscotch' | 'okaidia' | 'pojoaque' | 'prism' | 'solarizedlight' | 'tomorrow' | 'twilight' | 'vscDarkPlus' | 'xonokai';
export declare type LanguageType = 'python' | 'r' | 'julia' | 'haskell' | 'ruby';
export declare type HtmlFilter = (html: string) => string;
export declare type MetadataType = {
    [s: string]: any;
};
export declare type IpynbType = {
    cells: CellType[];
    worksheets?: {
        cells: CellType[];
    }[];
    nbformat?: number;
    nbformat_minor?: number;
    metadata?: MetadataType;
};
export declare type BaseProps = {
    ipynb: IpynbType;
    syntaxTheme?: SyntaxThemeType;
    language?: LanguageType;
    bgTransparent?: boolean;
    htmlFilter?: HtmlFilter;
    seqAsExecutionCount?: boolean;
};
export declare type MarkdownProps = {
    className: string;
    text: string;
};
export declare type ContextType = {
    syntaxTheme: SyntaxThemeType;
    language: LanguageType;
    bgTransparent: boolean;
    Markdown: React.FC<MarkdownProps>;
    htmlFilter: HtmlFilter;
    markdownOptions: any;
    seqAsExecutionCount: boolean;
};
export declare type CellAction = {
    index: number;
    cell?: CellType;
    ipynb?: IpynbType;
};
export declare type CellProps = {
    key?: string | number;
    cell: CellType;
    index: number;
    seq: number;
    showHeader?: boolean;
    readonly?: boolean;
    autoFocus?: boolean;
    editorFocus?: boolean;
    onEditorBlur?: () => void;
    onEditorFocus?: () => void;
    onEditorLoad?: (editor: any) => void;
    onChange?: (cell: CellType) => void;
    onDelete?: (cell: CellType) => void;
    onMoveUp?: (cell: CellType) => void;
    onMoveDown?: (cell: CellType) => void;
    onInsertAbove?: (cell: CellType) => void;
    onInsertBelow?: (cell: CellType) => void;
    onChangeCellType?: (cell: CellType) => void;
    onHover?: () => void;
    onFocus?: () => void;
    onMouseEnter?: () => void;
    onMouseLeave?: () => void;
    onRun?: (props: CellAction) => void;
    onRunInsertBelow?: (props: CellAction) => void;
    onRunInsertAbove?: (props: CellAction) => void;
    onRunSelectBelow?: (props: CellAction) => void;
};
 * The function `ArrayInsertElement` inserts an element into an array at a specified index and returns
 * the modified array.
 * @param array - The array parameter is the array in which you want to insert an element.
 * @param {number} index - The index parameter specifies the position at which the element should be
 * inserted in the array.
 * @param {Type} element - The `element` parameter is the value that you want to insert into the array.
 * @returns the modified array after inserting the element at the specified index.
export declare function arrayInsertElement<Type>(array: Array<Type>, index: number, element: Type): typeof array;
export declare function arrayMoveElement<Type>(array: Array<Type>, fromIndex: number, toIndex: number): typeof array;
 * The function `NewCell` returns a new cell object with default values.
 * @returns The function `NewCell` returns an object of type `CellType`.
export declare function NewCell(): CellType;
export declare function PasteCell(cell: CellType): CellType;
export declare type Ipynb = IpynbType;
export declare type Props = BaseProps & {
    markdownOptions?: MarkdownOptionsForMathjax;
    onChange?: (ipynb: IpynbType) => void;
    onEditorLoad?: (editor: any) => void;
    onCellFocus?: (index: number) => void;
    onCellHover?: (index: number) => void;
    onRun?: (prop: CellAction) => void;
    onSave?: (ipynb: IpynbType) => void;
    onRestartKernel?: () => void;
    readonly?: boolean;
};
export declare const IpynbEditor: React.FC<Props>;
export declare type Props = BaseProps & {
    markdownOptions?: MarkdownOptionsForKatex;
};
export declare const IpynbEditor: React.FC<Props>;
export declare type Props = {
    cell: CellType;
    show: boolean;
    onEnableEdit?: (enable: boolean) => void;
    onChange?: (cell: CellType) => void;
    onDelete?: (cell: CellType) => void;
    onMoveUp?: (cell: CellType) => void;
    onMoveDown?: (cell: CellType) => void;
    onInsertAbove?: (cell: CellType) => void;
    onInsertBelow?: (cell: CellType) => void;
    onChangeCellType?: (cell: CellType) => void;
};
export declare const CellHeader: React.FC<Props>;
export declare type MarkdownOptionsForKatex = {
    remarkMath?: typeof defaultRemarkMath;
    remarkMathOptions?: RemarkMathOptions;
    katexOptions?: KatexOptions;
};
export declare const MarkdownForKatex: React.FC<MarkdownProps>;
export declare type MarkdownOptionsForMathjax = {
    remarkMath?: typeof defaultRemarkMath;
    remarkMathOptions?: RemarkMathOptions;
    mathjaxOptions?: MathJaxOptions;
};
export declare const MarkdownForMathjax: React.FC<MarkdownProps>;
export declare const Cell: React.FC<CellProps>;